==> haskell-skylighting-core-0.14.2-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-core
version:              0.14.2
visibility:           public
id:                   skylighting-core-0.14.2-68IvbucFBVnB6KXoJAAGZy
key:                  skylighting-core-0.14.2-68IvbucFBVnB6KXoJAAGZy
license:              BSD-3-Clause
copyright:            (C) 2016-2024 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             syntax highlighting library
description:
    Skylighting is a syntax highlighting library.
    It derives its tokenizers from XML syntax
    definitions used by KDE'\''s KSyntaxHighlighting
    framework, so any syntax supported by that
    framework can be added. An optional command-line
    program is provided.
    Skylighting is intended to be the successor to
    highlighting-kate.
    This package provides the core highlighting
    functionality under a permissive license. It also
    bundles XML parser definitions licensed under the
    GPL.

category:             Text
abi:                  af5e80ba01512c159552a8815b830393
exposed:              True
exposed-modules:
    Skylighting.Core Skylighting.Loader Skylighting.Parser
    Skylighting.Regex Skylighting.Styles Skylighting.Tokenizer
    Skylighting.Types

hidden-modules:
    Regex.KDE Regex.KDE.Regex Regex.KDE.Compile Regex.KDE.Match

import-dirs:          /usr/lib/ghc-9.4.8/site-local/skylighting-core-0.14.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/skylighting-core-0.14.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/skylighting-core-0.14.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-core
hs-libraries:         HSskylighting-core-0.14.2-68IvbucFBVnB6KXoJAAGZy
depends:
    aeson-2.1.2.1-wY4CXNP4Ti6TCaMY1tyMf
    attoparsec-0.14.4-GTfBnxih117FV8L70A8efO base-4.17.2.1
    base64-bytestring-1.2.1.0-3xTWh9pwP9a781vByOHbcb binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-A6Av13j1PriHVZgHNthY8h
    colour-2.3.6-5kduP8EJo8q50TTkpFMjx8 containers-0.6.7
    directory-1.3.7.1 filepath-1.4.2.2 mtl-2.2.2
    safe-0.3.21-8UNW4gIoNRmKgGFufdPOla text-2.0.2 transformers-0.5.6.2
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    xml-conduit-1.9.1.4-KElFGaHf96E1O2VwBID5qq

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-core/html/skylighting-core.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-core/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-core-0.14.2-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-core
version:              0.14.2
visibility:           public
id:                   skylighting-core-0.14.2-8yXfHQl8wYh2r4FBxCCiQt
key:                  skylighting-core-0.14.2-8yXfHQl8wYh2r4FBxCCiQt
license:              BSD-3-Clause
copyright:            (C) 2016-2024 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             syntax highlighting library
description:
    Skylighting is a syntax highlighting library.
    It derives its tokenizers from XML syntax
    definitions used by KDE'\''s KSyntaxHighlighting
    framework, so any syntax supported by that
    framework can be added. An optional command-line
    program is provided.
    Skylighting is intended to be the successor to
    highlighting-kate.
    This package provides the core highlighting
    functionality under a permissive license. It also
    bundles XML parser definitions licensed under the
    GPL.

category:             Text
abi:                  a1f49574eb354398c25e83a82c74cb42
exposed:              True
exposed-modules:
    Skylighting.Core Skylighting.Loader Skylighting.Parser
    Skylighting.Regex Skylighting.Styles Skylighting.Tokenizer
    Skylighting.Types

hidden-modules:
    Regex.KDE Regex.KDE.Regex Regex.KDE.Compile Regex.KDE.Match

import-dirs:          /usr/lib/ghc-9.4.8/site-local/skylighting-core-0.14.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/skylighting-core-0.14.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/skylighting-core-0.14.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-core
hs-libraries:         HSskylighting-core-0.14.2-8yXfHQl8wYh2r4FBxCCiQt
depends:
    aeson-2.1.2.1-Eu0ZMA1fvZJ7acphaZ1YUp
    attoparsec-0.14.4-AaLxHw66o7ZDAbKIqXiED8 base-4.17.2.1
    base64-bytestring-1.2.1.0-9yKKMU9vx4T3mbm91B7Hi9 binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-ELM66iRIeZm6Dg1Td1yG95
    colour-2.3.6-JQk97xPN0JfIXlQGuAtpoj containers-0.6.7
    directory-1.3.7.1 filepath-1.4.2.2 mtl-2.2.2
    safe-0.3.21-29OHNU5kqwB6czdAzMhG9H text-2.0.2 transformers-0.5.6.2
    utf8-string-1.0.2-JoSH3X8qo5Q4jcipebjMdu
    xml-conduit-1.9.1.4-WdiHh6eI6cLQXQ9Zt6bLQ

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-core/html/skylighting-core.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-core/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
